package com.lzmispt.data.resource.service.monitor.impl;

package .tmp;

import com.alibaba.cloud.commons.lang.StringUtils;
import com.lzmispt.data.center.entity.dto.databasestruct.DataSourceDTO;
import com.lzmispt.data.center.entity.dto.resource.apply.GetDataTableConnectionInfoVO;
import com.lzmispt.data.center.entity.dto.resource.lzdpdevelop.GetTableDTO;
import com.lzmispt.data.center.entity.enums.BaseSysFieldEnum;
import com.lzmispt.data.center.entity.vo.resource.lzdpdevelop.TableVO;
import com.lzmispt.data.center.entity.vo.statistics.CommonDataCountVO;
import com.lzmispt.data.center.entity.vo.statistics.GetDataInterfaceVO;
import com.lzmispt.data.resource.client.DataApplyClient;
import com.lzmispt.data.resource.dao.monitor.IMonitoringPlatformDao;
import com.lzmispt.data.resource.entity.dto.monitor.CheckInterfaceListDTO;
import com.lzmispt.data.resource.entity.po.monitor.TableStatisticsPO;
import com.lzmispt.data.resource.entity.vo.monitor.DataPushMonitorVo;
import com.lzmispt.data.resource.service.lzdpdevelop.ILZDPApi;
import com.lzmispt.data.resource.service.monitor.impl.PlatDataQueryManager;
import com.lzmispt.dcbase.ServiceUtil;
import com.lzmispt.dcbase.databasestruct.DataStructProvider;
import com.lzmispt.dcbase.sysfield.SysFieldHelper;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.log.LogHelper;
import feign.Request;
import java.util.List;
import java.util.concurrent.TimeUnit;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;

@Service
public class ApplyDataQueryImpl extends PlatDataQueryManager {
  private static final int GET_TOTAL_DATA_COUNT_TIME_OUT = 6000;
  
  @Autowired
  private DataApplyClient dataApplyClient;
  
  @Autowired
  ILZDPApi ilzdpApi;
  
  public CommonDataCountVO getCommonDataCount() {
    return (CommonDataCountVO)this.dataApplyClient.getCommonDataCount("0").getObj();
  }
  
  public Integer getTotalDataCount() {
    return (Integer)this.dataApplyClient.getTotalDataCount(new Request.Options(6000L, TimeUnit.SECONDS, 6000L, TimeUnit.SECONDS, true), "0").getObj();
  }
  
  public Integer getDataTableDataCountById(Long entityId, Integer res, String toeknId) {
    ResultEntity<GetDataTableConnectionInfoVO> connectInfoResult = this.dataApplyClient.getDataTableConnectionInfo(entityId, "0");
    if (connectInfoResult == null || connectInfoResult.getObj() == null)
      return null; 
    GetDataTableConnectionInfoVO connectInfo = (GetDataTableConnectionInfoVO)connectInfoResult.getObj();
    if (StringUtils.isEmpty(connectInfo.getTableName()) || connectInfo.getDataSourceInfo() == null) {
      LogHelper.info("tableId: " + entityId + " 数据源连接信息获取失败或表名为空，无法查询数据量");
      return null;
    } 
    GetDataTableConnectionInfoVO.DataSourceInfo dataSourceInfo = connectInfo.getDataSourceInfo();
    DataSourceDTO dataSourceDTO = new DataSourceDTO();
    dataSourceDTO.setType(dataSourceInfo.getDbType());
    dataSourceDTO.setUser(dataSourceInfo.getUsername());
    dataSourceDTO.setDbSchema(dataSourceInfo.getDbSchema());
    dataSourceDTO.setDbName(connectInfo.getDbName());
    dataSourceDTO.setPort(dataSourceInfo.getPort());
    dataSourceDTO.setIpName(dataSourceInfo.getDataSourceUrl());
    dataSourceDTO.setPassword(dataSourceInfo.getPassword());
    ResultEntity<DataStructProvider> getDataBaseProviderRet = DataStructProvider.getDataBaseProvider(dataSourceDTO, true, false);
    if (!getDataBaseProviderRet.getCode().equals(Integer.valueOf(0))) {
      LogHelper.error("获取的数据源失败,原因：" + getDataBaseProviderRet.getMsg());
      return null;
    } 
    return selectTableDataCount(connectInfo.getTableName(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.IS_DELETE), (DataStructProvider)getDataBaseProviderRet.getObj());
  }
  
  public String getDefaultCode() {
    return "Apply";
  }
  
  public Integer getSpecialDatabaseCount() {
    return (Integer)this.dataApplyClient.getSpecialDatabaseCount("0").getObj();
  }
  
  public Integer getApplyInterfaceCount() {
    return (Integer)this.dataApplyClient.getApplyInterfaceCount("0").getObj();
  }
  
  public List<DataPushMonitorVo> getDataPushMonitorVo(String token) {
    ResultEntity<List<DataPushMonitorVo>> dataPushMonitorVo = this.dataApplyClient.getDataPushMonitorVo("0");
    return (List<DataPushMonitorVo>)dataPushMonitorVo.getObj();
  }
  
  public String getTableNameById(String tableId) throws Exception {
    GetTableDTO getTableDTO = new GetTableDTO();
    int middle = tableId.length() / 2;
    tableId = tableId.substring(middle, tableId.length());
    getTableDTO.setTable_id("Apply_" + tableId);
    ResultEntity<TableVO> tableStructure = this.dataApplyClient.getTableStructure(getTableDTO, "0");
    if (ObjectUtils.isEmpty(tableStructure.getObj())) {
      deleteDataTableById(tableId);
      return "";
    } 
    TableVO tableVO = (TableVO)tableStructure.getObj();
    return tableVO.getTable_cn_name();
  }
  
  public String setTableId(Integer tablePlatCode, String tableId) {
    int middle = tableId.length() / 2;
    String repositoryId = tableId.substring(0, middle);
    tableId = tableId.substring(middle, tableId.length());
    return getDefaultCode() + "_" + repositoryId + "_" + tableId;
  }
  
  public ResultEntity<Boolean> deleteDataTableById(String id) {
    TableStatisticsPO tableStatisticsPO = new TableStatisticsPO();
    tableStatisticsPO.setTableId(id);
    tableStatisticsPO.setIsShow(Integer.valueOf(0));
    tableStatisticsPO.setIsDelete(Integer.valueOf(1));
    Boolean flag = Boolean.valueOf(false);
    try {
      Integer integer = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).deleteDataTableById(tableStatisticsPO);
      if (integer.intValue() > 0)
        flag = Boolean.valueOf(true); 
    } catch (Exception e) {
      LogHelper.error("【监控平台-报警配置删除数据表" + id + " 失败】，具体信息为：" + e.getMessage());
    } 
    return ResultEntity.successMessage(flag);
  }
  
  public String getInterfaceName(Integer tablePlatCode, Long interfaceId) {
    CheckInterfaceListDTO getInterfaceDTO = new CheckInterfaceListDTO();
    getInterfaceDTO.setIsAll(Boolean.valueOf(true));
    ResultEntity<List<GetDataInterfaceVO>> checkDataInterfaceList = this.dataApplyClient.getCheckDataInterfaceList("0", getInterfaceDTO);
    List<GetDataInterfaceVO> interfaceVOList = (List<GetDataInterfaceVO>)checkDataInterfaceList.getObj();
    if (!CollectionUtils.isEmpty(interfaceVOList))
      return getInterApplyName((List<GetDataInterfaceVO>)checkDataInterfaceList.getObj(), interfaceId); 
    return interfaceId + "";
  }
  
  public String getInvokeUserName(Long userId) {
    return null;
  }
  
  private String getInterApplyName(List<GetDataInterfaceVO> interfaceList, Long interfaceId) {
    if (!ObjectUtils.isEmpty(interfaceList))
      for (GetDataInterfaceVO getInterfaceInfoVO : interfaceList) {
        if (getInterfaceInfoVO.getInterfaceId().intValue() == interfaceId.intValue())
          return getInterfaceInfoVO.getInterfaceName(); 
      }  
    return interfaceId + "";
  }
}
